@@ -22,21 +22,14 @@
 #ifndef THINKFAN_CONFIG_H_
 #define THINKFAN_CONFIG_H_
 
-#include "error.h"
+#include "temperature_state.h"
 
-#include <string>
 #include <vector>
-#include <memory>
-#include <map>
 
-#include "fans.h"
-#include "sensors.h"
 #include "thinkfan.h"
 
 namespace thinkfan {
 
-class Config;
-
 class FanConfig {
 public:
 	FanConfig(unique_ptr<FanDriver> && = nullptr);
@@ -123,29 +116,28 @@ private:
 
 class Config {
 public:
-	Config();
-	// Not trivially copyable since it holds raw pointers to levels, drivers and fans.
-	Config(const Config &) = delete;
+	Config() = default;
 	~Config() = default;
+
 	static const Config *read_config(const vector<string> &filenames);
 	void add_sensor(unique_ptr<SensorDriver> &&sensor);
 	void add_fan_config(unique_ptr<FanConfig> &&fan_cfg);
 	void ensure_consistency() const;
 	void init_fans() const;
+	TemperatureState init_sensors() const;
+	void init_temperature_refs(TemperatureState &tstate) const;
+	void init(TemperatureState &ts) const;
 
 	unsigned int num_temps() const;
 	const vector<unique_ptr<SensorDriver>> &sensors() const;
 	const vector<unique_ptr<FanConfig>> &fan_configs() const;
 
-	// No copy assignment operator either (not required).
-	Config &operator = (const Config &) = delete;
-
 	string src_file;
 private:
 	static const Config *try_read_config(const string &data);
+	void try_init_driver(Driver &drv) const;
 	vector<unique_ptr<SensorDriver>> sensors_;
 	vector<unique_ptr<FanConfig>> temp_mappings_;
-	unsigned int num_temps_;
 };
 
 
