@@ -19,10 +19,10 @@
  *
  * ******************************************************************/
 
-#include "error.h"
 #include "thinkfan.h"
 #include "message.h"
 #include "config.h"
+#include "fans.h"
 #include <syslog.h>
 #include <iostream>
 
@@ -60,6 +60,23 @@ LogLevel &operator++(LogLevel &l)
 }
 
 
+Logger &log(LogLevel lvl)
+{
+	Logger::instance().level(lvl);
+	return Logger::instance();
+}
+
+
+Logger &flush(Logger &l)
+{ return l.flush(); }
+
+Logger &log()
+{ return Logger::instance(); }
+
+
+
+
+
 Logger::Logger()
 : syslog_(false),
   log_lvl_(DEFAULT_LOG_LVL),
@@ -78,16 +95,6 @@ LogLevel &Logger::log_lvl()
 { return log_lvl_; }
 
 
-Logger &flush(Logger &l) { return l.flush(); }
-
-
-Logger &log(LogLevel lvl)
-{
-	Logger::instance().level(lvl);
-	return Logger::instance();
-}
-
-
 Logger::~Logger()
 {
 	flush();
@@ -106,19 +113,13 @@ void Logger::enable_syslog()
 
 Logger &Logger::flush()
 {
-	if (msg_pfx_.length() == 0) return *this;
+	if (msg_pfx_.length() == 0)
+		return *this;
 	if (msg_lvl_ <= log_lvl_) {
-		if (syslog_) {
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wformat-security"
-			// I think we can safely do this because thinkfan doesn't receive
-			// any data from unprivileged processes.
-			syslog(msg_lvl_, msg_pfx_.c_str());
-#pragma GCC diagnostic pop
-		}
-		else {
+		if (syslog_)
+			syslog(msg_lvl_, "%s", msg_pfx_.c_str());
+		else
 			std::cerr << msg_pfx_ << std::endl;
-		}
 	}
 	msg_pfx_ = "";
 
@@ -196,4 +197,5 @@ Logger &Logger::operator<< (const vector<unique_ptr<FanConfig>> &fan_configs)
 
 
 
+
 }
