@@ -25,9 +25,9 @@
 #include <syslog.h>
 #include <string>
 #include <exception>
-#include <memory>
 
 #include "thinkfan.h"
+#include "temperature_state.h"
 
 namespace thinkfan {
 
@@ -93,7 +93,9 @@ private:
 	std::exception_ptr exception_;
 };
 
+
 Logger &flush(Logger &l);
+Logger &log();
 Logger &log(LogLevel lvl);
 
 template<class ErrT, class... ArgTs> void error(const ArgTs &... args) {
@@ -103,7 +105,9 @@ template<class ErrT, class... ArgTs> void error(const ArgTs &... args) {
 		log(TF_ERR) << ErrT(args...).what() << flush;
 }
 
-}
+
+} // namespace thinkfan
+
 
 #ifdef USE_ATASMART
 #define DND_DISK_HELP \
@@ -119,7 +123,7 @@ template<class ErrT, class... ArgTs> void error(const ArgTs &... args) {
  "\n -h  This help message" \
  "\n -s  Maximum cycle time in seconds (Integer. Default: 5)" \
  "\n -b  Floating point number (-10 to 30) to control rising temperature" \
- "\n     exaggeration (see README). Default: 5.0" \
+ "\n     exaggeration (see thinkfan(5)). Default: 0.0" \
  "\n -c  Load different configuration file (default: /etc/thinkfan.conf)" \
  "\n -n  Do not become a daemon and log to terminal instead of syslog" \
  "\n -q  Be more quiet. Can be specified up to three times so that only errors" \
@@ -156,12 +160,14 @@ template<class ErrT, class... ArgTs> void error(const ArgTs &... args) {
 #define MSG_T_GET(file) string(__func__) + ": Failed to read temperature(s) from " + file + ": "
 #define MSG_T_INVALID(s, d) s + ": Invalid temperature: " + std::to_string(d)
 #define MSG_SENSOR_INIT(file) string(__func__) + ": Initializing sensor in " + file + ": "
-#define MSG_HWMON_NOT_FOUND "Could not find a hwmon with this name"
 #define MSG_MULTIPLE_HWMONS_FOUND "Found multiple hwmons with this name: "
 
 
 #define MSG_FAN_MODOPTS \
- "Module thinkpad_acpi doesn't seem to support fan_control"
+ "Kernel module thinkpad_acpi: Fan_control seems disabled. See this link:\n" \
+ "https://www.kernel.org/doc/html/latest/admin-guide/laptops/thinkpad-acpi.html?highlight=thinkpad_acpi#fan-control-and-monitoring-fan-speed-fan-enable-disable\n" \
+ "Or execute the following as root:\n" \
+ "echo \"options thinkpad_acpi fan_control=1\" > /etc/modprobe.d/99-thinkfan.conf"
 #define MSG_FAN_CTRL(str, fan) string(__func__) + ": Writing \"" + str + "\" to " + fan + ": "
 #define MSG_FAN_INIT(fan) string(__func__) + ": Initializing fan control in " + fan + ": "
 #define MSG_FAN_RESET(fan) string(__func__) + ": Resetting fan control in " + fan + ": "
